from .base import BaseCFObject


class Transformation(BaseCFObject):
    top_level_key = "Transform"
